@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -135,11 +135,23 @@ class TEMPLATEPARSER_EXPORT TemplateParserJob : public QObject
     friend class TemplateParserJobTest;
 
 public:
-    enum Mode { NewMessage, Reply, ReplyAll, Forward };
+    enum Mode {
+        NewMessage,
+        Reply,
+        ReplyAll,
+        Forward,
+    };
 
-    enum AllowSelection { SelectionAllowed, NoSelectionAllowed };
+    enum AllowSelection {
+        SelectionAllowed,
+        NoSelectionAllowed,
+    };
 
-    enum Quotes { ReplyAsOriginalMessage, ReplyAsPlain, ReplyAsHtml };
+    enum Quotes {
+        ReplyAsOriginalMessage,
+        ReplyAsPlain,
+        ReplyAsHtml,
+    };
 
 public:
     explicit TemplateParserJob(const KMime::Message::Ptr &amsg, const Mode amode, QObject *parent = nullptr);
@@ -336,14 +348,14 @@ private:
      * Does the necessary conversions like escaping characters, changing "\n" to
      * breakline tag before appending text to htmlBody.
      */
-    static Q_REQUIRED_RESULT QString plainTextToHtml(const QString &body);
+    Q_REQUIRED_RESULT static QString plainTextToHtml(const QString &body);
 
     /**
      * Make a HTML content valid by adding missing html/head/body tag.
      */
     void makeValidHtml(QString &body);
 
+    friend class ::TemplateParserJobTest;
     std::unique_ptr<TemplateParserJobPrivate> d;
 };
 }
-
