@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -76,10 +76,7 @@ LocalDataBaseFile::LocalDataBaseFile(const QString &filename)
     d->load();
 }
 
-LocalDataBaseFile::~LocalDataBaseFile()
-{
-    delete d;
-}
+LocalDataBaseFile::~LocalDataBaseFile() = default;
 
 void LocalDataBaseFile::close()
 {
@@ -124,13 +121,13 @@ QByteArray LocalDataBaseFile::searchHash(const QByteArray &hashToSearch)
      * - one getUint64 => number of item
      * => 12
      */
-    int posListOffset = 12;
     const int numHash = getUint64(4);
-    int begin = 0;
     int end = numHash - 1;
     QByteArray previousValue;
     if (end > 0) {
         QByteArray currentValue;
+        int begin = 0;
+        int posListOffset = 12;
         do {
             previousValue = currentValue;
             const int medium = (begin + end) / 2;
