@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -25,6 +25,6 @@ Q_SIGNALS:
 
 private:
     QWebEngineView *const mWebEngineView;
-    QWebEnginePage *mEnginePage = nullptr;
+    QWebEnginePage *const mEnginePage;
 };
 }
